Changelog
---------
0.0.2 (2017-08-09)
~~~~~~~~~~~~~~~~~~~

- Allows to filter notices by a search term.
  [msom]

- Allows to filter notices by user IDs.
  [msom]

0.0.1 (2017-07-14)
~~~~~~~~~~~~~~~~~~

- Initial Release
